GuildChat = {}

local LC = LibStub('libChat-1.0')
local LGI = LibStub("LibGuildInfo-1.0")
local LAM = LibStub("LibAddonMenu-1.0")

local AllianceColours = { ["Aldmeri Dominion"] = "|cffff00", ["Daggerfall Convenant"]= "|c4169E1", ["Ebonhart Pact"] = "|c8B0000"}
local ClassColours = {["Dragon Knight"] = "ca0000", ["Sorcerer"] = "0096ff", ["Nightblade"] = "9900f1", ["Templar"] = "efefef"}

function GuildChat:GetLevel(name)	
	return LGI:GetLevelByMemberName(name) or 0
end

function GuildChat:GetClassColour(name)
	return ClassColours[LGI:GetClassNameByMemberName(name)] or "ffffff"
end

function GuildChat:GetLevelColour(name)
	return "|c9932CC"
end

function GuildChat:GetAtColour(name)
	return AllianceColours[LGI:GetAllianceNameByMemberName(name)] or "ffffff"
end

function GuildChat:GetPrintName(name)
	if GuildChat.settings.characterName == "character" then
		local guildmember = LGI:GetGuildMemberByMemberName("@" ..name)
		return guildmember and guildmember.characterName or name
	end
	return name
end

function GuildChat:GetGuildRank(name)
	return LGI:GetGuildRankByMemberName(name)
end

local ChanInfoArray = ZO_ChatSystem_GetChannelInfo()
local CategoryMapping = ZO_ChatSystem_GetEventCategoryMappings()

function GuildChat:GetName(channelId, fromName, text)
	local info = ChanInfoArray[channelId]
	local r,g,b = GetChatCategoryColor(CategoryMapping[EVENT_CHAT_MESSAGE_CHANNEL][channelId])
	local baseColour = ZO_ColorDef:New(r, g, b, 1)

	local nameLink = (info.playerLinkable and not fromName:find("%[")) and ZO_LinkHandler_CreatePlayerLink(fromName:gsub("%^.+", "")) or fromName
	
	local formattedName = nil

	local  colour, display, charname, name = nameLink:match("^|H([^:]-):([^\[]-)%[([^@]-)@([^\]]-)%]|h")
		if colour then			
			formattedName = "|c" .. baseColour:ToHex() .."[" .. GuildChat:GetLevelColour("@" .. name) .. GuildChat:GetLevel("@" .. name) .. "|c" .. baseColour:ToHex() .. "]" ..							
							"[" .. (charname or "") .. GuildChat:GetAtColour("@" .. name) .."@" ..
							"|H" .. GuildChat:GetClassColour("@" .. name) .. ":" .. display .. GuildChat:GetPrintName(name) .. "|h" .. 
							"|c" .. baseColour:ToHex() .. "]"
			if GuildChat.settings.guildRank then 
				formattedName = "[" .. GuildChat:GetGuildRank("@" .. name) .. "]" .. formattedName
			end
		end

	return formattedName or nameLink
end

function GuildChat:Register()	
	LC:registerName(function(...) return GuildChat:GetName(...) end)	
end

function GuildChat:Loaded(...)
	local eventId, addonName = ...
	if addonName ~= "GuildChat" then return end	

	local defaults = {
			["characterName"] = "account",
			["guildRank"] = false,
	}
	
	GuildChat.settings = ZO_SavedVars:NewAccountWide('GuildChat_Settings', 2, nil, defaults)	
	local panel = LAM:CreateControlPanel("GuildChatMenu", "Guild Chat")
  
	LAM:AddHeader(panel, "GuildChatOptions", "Chat Options")
	LAM:AddDropdown(panel, "charName", "Set the name to be ", 
						"Guild Chat can display Account or Character name", 
						{"account", "character"}, function() return GuildChat.settings.characterName end,
						function(valueString) GuildChat.settings.characterName = valueString end)
	LAM:AddCheckbox(panel, "showGuildRank", "Show Guild Rank", "Include a rank indicator",
						function() return GuildChat.settings.guildRank end,
						function(value) GuildChat.settings.guildRank = not GuildChat.settings.guildRank end)
end

EVENT_MANAGER:RegisterForEvent("GuildChatLoaded", EVENT_ADD_ON_LOADED, function(...) GuildChat:Loaded(...) end)
EVENT_MANAGER:RegisterForEvent("GuildChatLoaded", EVENT_PLAYER_ACTIVATED, function(...) zo_callLater(GuildChat.Register, 5000) end)

